# frozen_string_literal: true

require 'spec_helper'
require_migration!

# the old schema date is one in which the regexp-based trigger does not
# exist
RSpec.describe BackfillReadthedocsIntegration, :migration, schema: 20210721135638 do
  let(:migration) { described_class.new }
  let(:namespaces) { table(:namespaces) }
  let(:projects) { table(:projects) }
  let(:integrations) { table(:integrations) }

  before do
    namespace = namespaces.create!(name: 'test', path: 'test')
    projects.create!(id: 1, namespace_id: namespace.id, name: 'gitlab', path: 'gitlab')
    integrations.create!(id: 1, active: true, type: "ReadthedocsService",
                         category: 'common', project_id: 1)
    integrations.create!(id: 3, active: true, type_new: "Integrations::Confluence", category: 'common', project_id: 1)
  end

  describe '#up' do
    it 'correctly adds type_new to Readthedocs integration and does not change others' do
      expect(integrations.find(1).type_new).to be_nil
      expect(integrations.find(3).type_new).to eq "Integrations::Confluence"

      migration.up
      expect(integrations.find(1).type_new).to eq "Integrations::Readthedocs"
      expect(integrations.find(3).type_new).to eq "Integrations::Confluence"
    end
  end
end
